@@ -44,7 +44,7 @@ UNREAD_COUNT_URL = READER_URL + '/api/0/unread-count'
 SUBSCRIPTION_LIST_URL = READER_URL + '/api/0/subscription/list'
 SUBSCRIPTION_EDIT_URL = READER_URL + '/api/0/subscription/edit'
 TAG_EDIT_URL = READER_URL + '/api/0/edit-tag'
-DISABLE_TAG_URL = READER_URL + '/api/0/disable-tag'
+TAG_DISABLE_URL = READER_URL + '/api/0/disable-tag'
 IN_STATE_URL = READER_URL + '/atom/user/-/state/com.google/%s'
 GET_FEED_URL = READER_URL + '/atom/feed/'
 READING_TAG_URL = READER_URL + '/atom/%s'
